@@ -73,13 +73,14 @@ class Interface:  # pragma no cover
         :type t: float
         :param y: states in numpy format
         :type y: :class:`numpy.ndarray`
-        :return: derivatives as array (if any, otherwise None)
+        :return: derivatives as array (if any, otherwise None or empty array)
         :rtype: :class:`numpy.ndarray`
         """
         return
 
     def get_states(self) -> np.array:
-        """Function to get states and return to solver. Must be implemented by user
+        """Function to get states and return to solver. Must be implemented by user. If model contains no states, the
+        function can return an empty array.
 
         :return: array of states
         :rtype: :class:`numpy.ndarray`
